@@ -1,5 +1,10 @@
+# add check for uncommitted or auto stash
+git update-index --refresh >/dev/null
+git diff-index --quiet HEAD --
 
-# define wehere the version file is found
+test $? -eq 0 || echo "ERROR: the repo is dirty clean it before building!"; exit 1
+
+# define where the version file is found
 VERSION_FILE=src/nef_pipelines/VERSION
 
 # cheange to the correct working directory
@@ -17,7 +22,7 @@ VERSION=`ver --file $VERSION_FILE |  awk '{print $3}'`
 
 # update the version  in the repo
 git add src/nef_pipelines/VERSION
-git commit -m "updated version to $VERSION"
+git commit -m "updated version to $VERSION" --no-verify
 
 # stash any uncommited changes to avoid version+1 errors
 git stash
