@@ -12,10 +12,15 @@ class Linking(StrEnum):
 
 
 @dataclass(frozen=True, order=True)
-class SequenceResidue:
+class Residue:
     chain_code: str
     sequence_code: Union[int, str]
     residue_name: str
+
+
+@dataclass(frozen=True, order=True)
+class SequenceResidue(Residue):
+
     is_cis: bool = False
     linking: Optional[Linking] = None
     variant: Optional[str] = None
@@ -24,7 +29,7 @@ class SequenceResidue:
 # should contain a residue and have constructors?
 @dataclass(frozen=True, order=True)
 class AtomLabel:
-    residue: SequenceResidue
+    residue: Residue
     atom_name: str
     element: str = None
     isotope_number: int = None
@@ -133,11 +138,13 @@ class LineInfo:
     line: str
 
 
-@dataclass
+@dataclass(frozen=True, order=True)
 class ShiftData:
     atom: AtomLabel
-    value: float
-    value_uncertainty: Optional[float] = None
+    value: float  # TODO: should be position
+    value_uncertainty: Optional[float] = None  # TODO: should be position_uncertainty
+    line_width: Optional[float] = None  # line width in Hz
+    line_width_uncertainty: Optional[float] = None  # uncertainty of line width in Hz
 
 
 @dataclass
@@ -152,3 +159,21 @@ class RdcRestraint:
     value: float
     value_uncertainty: float
     weight: Optional[float] = None
+
+
+@dataclass(frozen=True, order=True)
+class NewPeak:
+
+    shifts: List[ShiftData]
+
+    id: Optional[int] = None
+    height: Optional[float] = None
+    height_uncertainty: Optional[float] = None
+    volume: Optional[float] = None
+    volume_uncertainty: Optional[float] = None
+
+
+@dataclass
+class DimensionInfo:
+    axis_code: str  # this is the isotope code for us...
+    axis_unit: Optional[str] = "ppm"
