@@ -1,4 +1,5 @@
 import contextlib
+import inspect
 import io
 import os
 import sys
@@ -13,12 +14,12 @@ import click
 from cacheable_iter import iter_cache
 from pynmrstar import Entry, Loop, Saveframe
 from strenum import StrEnum
+from tabulate import tabulate
 
 from nef_pipelines.lib.constants import (
     EXIT_ERROR,
     NEF_META_DATA,
     NEF_PIPELINES,
-    NEF_PIPELINES_VERSION,
     NEF_UNKNOWN,
 )
 from nef_pipelines.lib.header_lib import (
@@ -107,7 +108,7 @@ def fixup_metadata(entry: Entry, name: str, version: str, script: str):
             )
             run_history_loop.add_data(["."] * 4)
     else:
-        header = create_header_frame(NEF_PIPELINES, NEF_PIPELINES_VERSION, script)
+        header = create_header_frame(NEF_PIPELINES, get_version(), script)
         entry.add_saveframe(header)
 
 
@@ -386,7 +387,7 @@ def _script_to_command(script: str) -> str:
     :return: the command name
     """
     script_path = script.split("/")
-    script_path[-1] = script_path[-1].strip(".py")
+    script_path[-1] = script_path[-1][: -len(".py")]
     return " ".join(script_path)
 
 
@@ -440,7 +441,7 @@ def process_stream_and_add_frames(
         exit_error(f"failed to load pipe file because {e}")
 
     if stream is not None:
-        lines = "".join(stream.readlines())
+        lines = "\n".join(stream.readlines())
     else:
         lines = ""
 
@@ -453,9 +454,7 @@ def process_stream_and_add_frames(
         else Entry.from_scratch(input_args.entry_name)
     )
 
-    fixup_metadata(
-        new_entry, NEF_PIPELINES, NEF_PIPELINES_VERSION, script_name(__file__)
-    )
+    fixup_metadata(new_entry, NEF_PIPELINES, get_version(), script_name(__file__))
 
     # TODO: check if frame exists
     for frame in frames:
@@ -702,6 +701,85 @@ def flatten(in_list: Union[List[Any], List[Union[List[Any], Any]]]) -> List[Any]
     :return: a list of anything but lists
     """
     out = []
-    for sublist in in_list:
-        out.extend(sublist)
+    for elem in in_list:
+        if not isinstance(elem, str):
+            out.extend(elem)
+        else:
+            out.append(elem)
     return out
+
+
+def get_version() -> str:
+    """
+        get the current version of nef pipelines
+    :return: a version string
+    """
+
+    file_path = Path(__file__)
+    root_path = file_path.parent.parent
+    version_path = root_path / "VERSION"
+
+    with open(version_path) as file_h:
+        version = file_h.read().strip()
+
+    return version
+
+
+class FStringTemplate:
+    """class for makes an f string based template substitution is delayed
+    until the instance is converted to a string
+    """
+
+    def __init__(self, template):
+        self.template = template
+
+    def __str__(self):
+        variables = inspect.currentframe().f_back.f_globals.copy()
+        variables.update(inspect.currentframe().f_back.f_locals)
+        return self.template.format(**variables)
+
+
+def unused_to_none(value: str) -> str:
+    """
+    If the value is a NEF UNUSED [.] replace it with None
+    :param value: value which might be UNUSED
+    :return: value or None if the value was UNUSED
+    """
+    from nef_pipelines.lib.nef_lib import (
+        UNUSED,  # to avoid circular import, move to constants?
+    )
+
+    if value == UNUSED:
+        value = None
+    return value
+
+
+def unused_to_empty_string(value):
+    """
+    If the value is a NEF UNUSED [.] replace it with the empty string
+    :param value: value which might be UNUSED
+    :return: value or "" if the value was UNUSED
+    """
+    from nef_pipelines.lib.nef_lib import (
+        UNUSED,  # to avoid circular import , move to constants?
+    )
+
+    if value == UNUSED:
+        value = ""
+    return value
+
+
+def _row_to_table(rows: Dict[str, str], headers=("tag", "value")) -> List[List[str]]:
+    """
+    convert a dictionary into a table with tabulate with two columns containing
+    keys and values
+    :param rows: a dictionary of key value pairs [tags and values...]
+    :return: a formatted tabulate table as a string
+    """
+    values = [
+        headers,
+    ]
+    for key, value in rows.items():
+        values.append([key, value])
+    value_string = tabulate(values, headers="firstrow")
+    return value_string
