@@ -75,6 +75,8 @@ def main():
         import nef_pipelines.tools.entry  # noqa: F401
         import nef_pipelines.tools.frames  # noqa: F401
         import nef_pipelines.tools.header  # noqa: F401
+        import nef_pipelines.tools.peaks  # noqa: F401
+        import nef_pipelines.tools.shifts  # noqa: F401
         import nef_pipelines.tools.stream  # noqa: F401
         import nef_pipelines.tools.test  # noqa: F401
         import nef_pipelines.transcoders.csv  # noqa: F401
@@ -84,6 +86,7 @@ def main():
         import nef_pipelines.transcoders.nmrview  # noqa: F401
         import nef_pipelines.transcoders.pales  # noqa: F401
         import nef_pipelines.transcoders.pdbx  # noqa: F401
+        import nef_pipelines.transcoders.rpf  # noqa: F401
         import nef_pipelines.transcoders.shifty  # noqa: F401
         import nef_pipelines.transcoders.sparky  # noqa: F401
         import nef_pipelines.transcoders.xcamshift  # noqa: F401
