@@ -39,8 +39,8 @@ def test_lib_parse_shifts():
                     ),
                     atom_name="N",
                 ),
-                shift=125.74,
-                error=None,
+                value=125.74,
+                value_uncertainty=None,
             ),
             ShiftData(
                 atom=AtomLabel(
@@ -49,8 +49,8 @@ def test_lib_parse_shifts():
                     ),
                     atom_name="HN",
                 ),
-                shift=8.31,
-                error=None,
+                value=8.31,
+                value_uncertainty=None,
             ),
         ]
     )
@@ -80,14 +80,14 @@ def test_ns3_S135A_BMRB1_short():
            _nef_chemical_shift_list.sf_framecode  nef_chemical_shift_list_nmrpipe
 
            loop_
-              _nef_chemical_shift_list.chain_code
-              _nef_chemical_shift_list.sequence_code
-              _nef_chemical_shift_list.residue_name
-              _nef_chemical_shift_list.atom_name
-              _nef_chemical_shift_list.value
-              _nef_chemical_shift_list.value_uncertainty
-              _nef_chemical_shift_list.element
-              _nef_chemical_shift_list.isotope_number
+              _nef_chemical_shift.chain_code
+              _nef_chemical_shift.sequence_code
+              _nef_chemical_shift.residue_name
+              _nef_chemical_shift.atom_name
+              _nef_chemical_shift.value
+              _nef_chemical_shift.value_uncertainty
+              _nef_chemical_shift.element
+              _nef_chemical_shift.isotope_number
 
              A   1   ALA   N     125.74   .   .   .
              A   1   ALA   C     179.08   .   .   .
@@ -114,14 +114,14 @@ def test_residue_1let_3let_translation():
             _nef_chemical_shift_list.sf_framecode  nef_chemical_shift_list_nmrpipe
 
             loop_
-                _nef_chemical_shift_list.chain_code
-                _nef_chemical_shift_list.sequence_code
-                _nef_chemical_shift_list.residue_name
-                _nef_chemical_shift_list.atom_name
-                _nef_chemical_shift_list.value
-                _nef_chemical_shift_list.value_uncertainty
-                _nef_chemical_shift_list.element
-                _nef_chemical_shift_list.isotope_number
+                _nef_chemical_shift.chain_code
+                _nef_chemical_shift.sequence_code
+                _nef_chemical_shift.residue_name
+                _nef_chemical_shift.atom_name
+                _nef_chemical_shift.value
+                _nef_chemical_shift.value_uncertainty
+                _nef_chemical_shift.element
+                _nef_chemical_shift.isotope_number
 
                 A   1   MET   CB   33.27    .   .   .
                 A   1   MET   CA   54.45    .   .   .
