@@ -4,7 +4,7 @@ from pathlib import Path
 
 import typer
 
-from nef_pipelines.lib.nef_lib import create_entry_from_stdin_or_exit
+from nef_pipelines.lib.nef_lib import read_entry_from_stdin_or_exit
 from nef_pipelines.transcoders.mars import export_app
 
 MARS_DEFAULT_FILE = "mars.inp"
@@ -44,18 +44,18 @@ def input(
 ):
     """- convert nef file to mars input"""
 
-    entry = create_entry_from_stdin_or_exit()
+    entry = read_entry_from_stdin_or_exit()
 
     output_file = f"{entry.entry_id}_mars.inp" if output_file is None else output_file
     pred_file = (
-        f"{entry.entry_id}_mars_pred.tab"
+        f"{entry.entry_id}_pred.tab"
         if output_file is None
         else convert_output_to(output_file, "_pred", "tab")
     )
     ass_file = (
-        f"{entry.entry_id}_mars_ass.tab"
+        f"{entry.entry_id}_fix_ass.tab"
         if output_file is None
-        else convert_output_to(output_file, "_ass", "tab")
+        else convert_output_to(output_file, "_fix_ass", "tab")
     )
 
     deuterated = int(deuterated)
